MlmsLoadPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MlmsLoadPlatform
Implementers

Constructors

MlmsLoadPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBuildVersion() Future<String?>
getPushToken() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MlmsLoadPlatform
getter/setter pair